A vector of ranks describing x such that x[order(ranks)]
will move priority_values to the front of the vector
Arguments
x
A character vector.
priority_values
A character vector descibing "priority" values. Elements of x matching
priority_values will be ranked based on their order of appearance in priority_values
ties.method
a character string specifying how ties are treated,
see ‘Details’; can be abbreviated.